/*============================================================================
	File:		0001 - create database and relations.sql

	Summary:	This script creates a demo database which will be used for
				the future demonstration scripts


	Date:		Mrz 2014

	SQL Server Version: 2008 / 2012
------------------------------------------------------------------------------
	Written by Uwe Ricken, db Berater GmbH

	This script is intended only as a supplement to demos and lectures
	given by Uwe Ricken.  
  
	THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
	ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
	TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
	PARTICULAR PURPOSE.
============================================================================*/
SET LANGUAGE deutsch;
USE master;
GO

-- if the database exists we drop it for a brand new database
IF db_id('demo_db') IS NOT NULL
BEGIN
	RAISERROR ('Database demo_db will be dropped first!', 0, 0) WITH NOWAIT;
	ALTER DATABASE demo_db SET SINGLE_USER WITH ROLLBACK IMMEDIATE;
	DROP DATABASE demo_db;
END
GO

RAISERROR ('Database demo_db will be created!', 0, 0) WITH NOWAIT;
CREATE DATABASE demo_db
ON PRIMARY
(
	Name = 'demo_db',
	FILENAME = 'S:\MSSQL11.SQL_2012\MSSQL\DATA\\demo_db.mdf',
	SIZE = 100MB,
	MAXSIZE = 1000MB,
	FILEGROWTH = 100MB
)
LOG ON
(
	NAME = 'demo_log',
	FILENAME = 'S:\MSSQL11.SQL_2012\MSSQL\DATA\\demo_db.ldf',
	SIZE = 100MB,
	MAXSIZE = 1000MB,
	FILEGROWTH = 100MB
);
GO

RAISERROR ('Owner of database demo_db will be set to sa!', 0, 1) WITH NOWAIT;
ALTER AUTHORIZATION ON DATABASE::demo_db TO sa;

-- for the demos concerning fn_dbLog() keep in mind to set the
-- RECOVERY model to full unless you want run investigation later on!
RAISERROR ('Recovery model of database demo_db will be set to SIMPLE!', 0, 1) WITH NOWAIT;
ALTER DATABASE demo_db SET RECOVERY SIMPLE;
GO

USE demo_db;
GO

RAISERROR ('Creation of example tables for demonstration of session information', 0, 1);
IF OBJECT_ID('dbo.Invoices', 'U') IS NOT NULL
	DROP TABLE dbo.Invoices;
	GO

IF OBJECT_ID('dbo.Customer', 'U') IS NOT NULL
	DROP TABLE dbo.Customer;
	GO

CREATE TABLE dbo.Customer
(
	Id				int				NOT NULL	IDENTITY (1, 1),
	CustomerName	varchar(255)	NOT NULL,
	CustomerStreet	varchar(100)	NOT NULL,
	CustomerCCode	varchar(3)		NOT NULL	DEFAULT ('DE'),
	CustomerZIP		varchar(10)		NOT NULL,
	CustomerCity	varchar(100)	NOT NULL,
	InsertUser		sysname			NOT NULL	DEFAULT (ORIGINAL_LOGIN()), CHECK (InsertUser = ORIGINAL_LOGIN()),
	InsertDate		datetime		NOT NULL	DEFAULT (GETDATE()),
	UpdateUser		sysname			NULL,
	UpdateDate		datetime		NULL,

	CONSTRAINT	pk_Customer PRIMARY KEY CLUSTERED (Id),
	CONSTRAINT	ix_Customer UNIQUE (CustomerName)
)
GO

IF OBJECT_ID('dbo.Invoices', 'U') IS NOT NULL
	DROP TABLE dbo.Invoices;
	GO

CREATE TABLE dbo.Invoices
(
	Id					int				NOT NULL	IDENTITY (1, 1),
	InvoiceNumber		char(8)			NOT NULL,
	InvoiceDate			date			NOT NULL,
	CustomerName		varchar(255)	NOT NULL,
	InvoiceStreet		varchar(100)	NOT NULL,
	InvoiceCCode		char(3)			NOT NULL,
	InvoiceZIP			varchar(10)		NOT NULL,
	InvoiceCity			varchar(100)	NOT NULL,
	InvoiceAmount		smallmoney		NOT NULL,
	InvoiceCurrency		char(3)			NOT NULL,
	InvoicePaymentDate	date			NULL,
	Customer_Id			int				NOT NULL
);
GO

/*
	no constraints on level of attributes
	no referencial integrity
*/

/* creation of default constraints */
ALTER TABLE dbo.invoices ADD CONSTRAINT df_invoices_invoicedate DEFAULT (GETDATE()) FOR InvoiceDate;
ALTER TABLE dbo.invoices ADD CONSTRAINT df_invoices_invoicececcode DEFAULT ('DE') FOR InvoiceCCode;
ALTER TABLE dbo.invoices ADD CONSTRAINT df_invoices_invoiceamount DEFAULT (0) FOR InvoiceAmount;
ALTER TABLE dbo.invoices ADD CONSTRAINT df_invoices_invoicecurrency DEFAULT ('') FOR InvoiceCurrency;
GO

/*	create foreign key for referencial integrity */
ALTER TABLE dbo.invoices ADD CONSTRAINT fk_Customer_Id FOREIGN KEY (Customer_Id)
REFERENCES dbo.Customer (Id)
ON DELETE CASCADE;
GO

RAISERROR ('Filling tables with data for tests', 0, 1) WITH NOWAIT;
SET NOCOUNT ON;
GO

INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('db Berater GmbH', 'Bahnstrasse 33', 'DE', '64390', 'Erzhausen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('cirquent GmbH', 'Knigsberger Strasse 29', 'DE', '60487', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Hays AG', 'Willy-Brandt-Platz 1-3', 'DE', '68161', 'Mannheim');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Logistic Office GmbH', 'Am Stadtholz 39', 'DE', '33609', 'Bielefeld');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('CBC Consult GmbH', 'Kaiserstrasse 44', 'DE', '60329', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Bauprojekt M & N GmbH', 'Bayerische Strasse 8', 'DE', '10707', 'Berlin');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('CenterConsult GmbH', 'Bundeskanzlerplatz 2 - 10', 'DE', '53175', 'Bonn');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Elan Telecommunications GmbH', 'Hautpstrasse 8b', 'DE', '82008', 'Unterhaching');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('CompuSafe Data Systems AG', 'Oetztaler Str. 18', 'DE', '81373', 'Mnchen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR', '75008', 'Paris');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE', '60313', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE', '60311', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('softbyte GmbH', 'Kornblumenweg 14', 'DE', '91056', 'Erlangen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V.', 'Kleiner Biergrund 18', 'DE', '63065', 'Offenbach am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Emerson Network Power Embedded Computing GmbH', 'Lilienthalstrasse 15', 'DE', '85579', 'Neubiberg');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('SR Stainless Recycling GmbH', 'Dieselstrasse 12', 'DE', '63456', 'Hanau');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('1st Point Consulting Services Gesellschaft fr Schulung und Systemberatung mbH', 'Pestalozzistrasse 72a', 'DE', '63322', 'Rdermark');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('IRL Industriesteuerungen GmbH Team PH21', 'Am Grundweg 20', 'DE', '64342', 'Seeheim-Jugenheim');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('avato consulting AG', 'Siemensstr. 24  26', 'DE', '63755', 'Alzenau');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Jnger+Grter GmbH', 'Robert-Bosch-Strae 1', 'DE', '68723', 'Schwetzingen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('GULP Information Services GmbH', 'Ridlerstrasse 37', 'DE', '80329', 'Mnchen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Software Development Mike Fried', 'Wiesengasse 3', 'DE', '64291', 'Darmstadt');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Arbeitgeberverband Leuchten- und Zubehr-Industrie e.V.', 'Kleiner Biergrund 18', 'DE', '63065', 'Offenbach am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('The Hunting Station GmbH', 'Kaiser-Friedrich-Promenade 61', 'DE', '61348', 'Bad Homburg');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Lenroxx GmbH', 'Speyerer Strasse 4', 'DE', '69115', 'Heidelberg');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('DB Private Equity GmbH', 'Schildergasse 120', 'DE', '50667', 'Kln');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('EFFICIENCY CLUB ZRICH', 'Bahnhofstrasse 37', 'CH', '8001', 'Zrich');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('BRAND EDV-Training & IT', 'Ostbahnhofstr. 13', 'DE', '60314', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('DIGEL AG', 'Calwer Strasse 81', 'DE', '72202', 'Nagold');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Scala Management Consulting GmbH Partner fr Strategie, Vernderung und Innovation', 'Stadttor 1', 'DE', '40219', 'Dsseldorf');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Advanced UniByte GmbH', 'Birnenweg 15', 'DE', '72766', 'Reutlingen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('ERBE Elektromedizin GmbH', 'Waldhrnlestrasse 17', 'DE', '72072', 'Tbingen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Deutsche Bank (Suisse) SA GT Production EMEA', 'Uraniastrasse 9', 'CH', '8001', 'Zurich');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Dieffenbacher GmbH & CO Betriebssttte Pfungstadt', 'Werner-von-Siemens-Strae 2', 'DE', '64319', 'Pfungstadt');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Swiss Post Solutions GmbH Division Document Output', 'Kirchheimer Strae 177', 'DE', '73265', 'Dettingen u. Teck');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('DST Consulting GmbH', 'Zettachring 8', 'DE', '70567', 'Stuttgart');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('tef-dokumentation Technische Dokumentation und Softwareentwicklung', 'Angelestrasse 56', 'DE', '88214', 'Ravensburg');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Brstner GmbH', 'Weststrae 33', 'DE', '77694', 'Kehl');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('EDC-Business Computing GmbH', 'Alexanderstrae 59', 'DE', '60489', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('LioNBRIDGE Technologies, Inc', 'Caleruega 102', 'E', '28033', 'Madrid');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('ORDIX AG Geschftsstelle Wiesbaden', 'Kreuzberger Ring 13', 'DE', '65205', 'Wiesbaden');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Herrenknecht AG', 'Schlehenweg 2', 'DE', '77963', 'Schwanau');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Concord Effekten AG', 'Groe Gallusstrae 1-7', 'DE', '60311', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('KLNDATA Professional IT Services GmbH Wissenschaftspark Osnabrck', 'Albert-Einstein-Strasse 1', 'DE', '49076', 'Osnabrck');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('allnabout GmbH', 'Hermannstrae 54', 'DE', '63263', 'Neu-Isenburg');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Stefan Schrer Projektbetreuung GmbH', 'Ostring 14', 'DE', '49661', 'Cloppenburg');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('salamon | it-service', 'Friedrichsplatz 11', 'DE', '34117', 'Kassel');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('IDAP GmbH', 'Leyboldstrae 12', 'DE', '50354', 'Hrth');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('ProTechnology GmbH', 'Antonstrae 3a', 'DE', '01097', 'Dresden');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('BRABENDER Solutions GmbH', 'Gewerbestr. 5a', 'CH', '6314', 'Untergeri');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Robert Koch Institut', 'Nordufer 20', 'DE', '13302', 'Berlin');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Q_PERIOR AG', 'Bavariaring 28', 'DE', '80336', 'Mnchen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('cleversoft CRM Services GmbH', 'Paul-Heyse-Str. 6', 'DE', '80336', 'Mnchen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Karl Donaubauer', 'Grinzinger Allee 5/14', 'AT', '1190', 'Wien');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('top itservices AG', 'Zeughausmarkt 17', 'DE', '20459', 'Hamburg');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE', '60311', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE', '1050', 'Bruxelles');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('American Chamber of Commerce in Italy', 'Via Cantu, 1', 'IT', '20123', 'Milano');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Swiss-American Chamber of Commerce', 'Talacker 41', 'CH', '8001', 'Zurich');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('American Chamber of Commerce in Poland', 'ul. Emilii Plater 53 13p.', 'PL', '00-113', 'Warsawa');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('European Central Bank', 'Kaiserstrae 29', 'DE', '60311', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE', '63477', 'Maintal');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Chausseestrae 22', 'DE', '10115', 'Berlin');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE', '60325', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Industrie- und Handelskammer Frankfurt am Main', 'Brsenplatz 4', 'DE', '60313', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE', '80333', 'Mnchen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('HWT Wassertechnische Anlagen GmbH', 'Am Dornbusch 15', 'DE', '64390', 'Erzhausen');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('PASS Consulting Group', 'Schwalbenrainweg 24', 'DE', '63741', 'Aschaffenburg');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('ACC Verlag & Services GmbH', 'Brsenplatz 7 - 11', 'DE', '60313', 'Frankfurt am Main');
INSERT INTO dbo.Customer (CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES ('Strer Out-of-Home Media AG', 'Strer Allee 1', 'DE', '50999', 'Kln');
GO

SET IDENTITY_INSERT dbo.Customer ON;
INSERT INTO dbo.Customer (Id, CustomerName, CustomerStreet, CustomerCCode, CustomerZIP, CustomerCity) VALUES (0, 'not assigned invoices', 'Musterstrasse', 'DE', '12345', 'Musterhausen');
SET IDENTITY_INSERT dbo.Customer OFF;
GO

INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070001', 'Jun 30 2007 12:00AM', 'Entory AG', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 6480.0000000, '', 'Jul 30 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070002', 'Jun 30 2007 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Romarkt 12', 'DE ', '60311', 'Frankfurt am Main', 4280.0000000, '', 'Jul 18 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070003', 'Jun 30 2007 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Strasse 8', 'DE ', '63477', 'Maintal', 10823.7500000, '', 'Aug  4 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070004', 'Jun 30 2007 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 2443.7500000, '', 'Jul 30 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070005', 'Jun 30 2007 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 440.0000000, '', 'Jul 16 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070006', 'Jun 30 2007 12:00AM', 'HWT Wassertechnische Anlagen GmbH', 'Am Dornbusch 15', 'DE ', '64390', 'Erzhausen', 320.0000000, '', 'Jul 27 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070007', 'Jun 30 2007 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 598.0000000, '', 'Jul 30 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070008', 'Aug  1 2007 12:00AM', 'entory AG', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 11664.0000000, '', 'Sep  3 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070009', 'Aug  1 2007 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Romarkt 12', 'DE ', '60311', 'Frankfurt am Main', 1620.0000000, '', 'Aug 21 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070010', 'Aug  1 2007 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 8240.0000000, '', 'Aug 28 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070011', 'Aug  1 2007 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 2920.0000000, '', 'Okt 10 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070012', 'Aug  1 2007 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 120.0000000, '', 'Aug 20 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070013', 'Aug  1 2007 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Einsteinring 3', 'DE ', '85609', 'Dornach-Mnchen', 2668.0000000, '', 'Aug 21 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070014', 'Aug  1 2007 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Einsteinring 3', 'DE ', '85609', 'Dornach-Mnchen', 765.0000000, '', 'Aug 21 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070015', 'Aug  1 2007 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 600.0000000, '', 'Dez 21 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070016', 'Aug  1 2007 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 260.0000000, '', 'Aug 22 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070017', 'Aug  1 2007 12:00AM', 'PASS Consulting Group', 'Schwalbenrainweg 24', 'DE ', '63741', 'Aschaffenburg', 184.0000000, '', 'Aug 28 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070018', 'Sep 30 2007 12:00AM', 'Bauprojekt M & N GmbH ', 'Bayerische Strasse 8', 'DE ', '10707', 'Berlin', 740.0000000, '', 'Okt 10 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070020', 'Sep  1 2007 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Romarkt 12', 'DE ', '60311', 'Frankfurt am Main', 2740.0000000, '', 'Sep 12 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080017', 'Apr 30 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 940.0000000, '', 'Jun 17 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070019', 'Sep  1 2007 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 14700.0000000, '', 'Sep 21 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070021', 'Sep  1 2007 12:00AM', 'Concord Effekten AG', 'Groe Gallusstrae 1-7', 'DE ', '60311', 'Frankfurt am Main', 220.0000000, '', 'Sep 19 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070022', 'Sep  1 2007 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Strubberg 70', 'DE ', '60489', 'Frankfurt am Main', 440.0000000, '', 'Sep  6 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080018', 'Apr 30 2008 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 2160.0000000, '', 'Jul 14 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070023', 'Sep  1 2007 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 1300.0000000, '', 'Okt 22 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070024', 'Sep  1 2007 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 1080.0000000, '', 'Sep 17 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070025', 'Sep  1 2007 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1530.0000000, '', 'Okt  2 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070026', 'Sep  1 2007 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 360.0000000, '', 'Sep 19 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070027', 'Sep  1 2007 12:00AM', 'entory AG', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 11962.0800000, '', 'Okt  8 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070028', 'Sep 30 2007 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', -740.0000000, '', 'Okt  1 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070029', 'Sep 30 2007 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 80.0000000, '', 'Okt  8 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070030', 'Sep 30 2007 12:00AM', 'American Chamber of Commerce in Poland', 'ul. Emilii Plater 53 13p.', 'PL ', '00-113', 'Warsawa', 2000.0000000, '', 'Nov 20 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070031', 'Sep 30 2007 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Romarkt 12', 'DE ', '60311', 'Frankfurt am Main', 3712.3900000, '', 'Okt 22 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070032', 'Sep 30 2007 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 675.0000000, '', 'Okt 29 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070033', 'Sep 30 2007 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 12200.0000000, '', 'Okt 24 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070034', 'Sep 30 2007 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 400.0000000, '', 'Dez 21 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070035', 'Sep 30 2007 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1020.0000000, '', 'Okt 30 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070036', 'Okt  1 2007 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Einsteinring 3', 'DE ', '85609', 'Mnchen', 552.0000000, '', 'Okt 30 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070038', 'Sep 30 2007 12:00AM', 'entory AG', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 9802.0800000, '', 'Okt 31 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080019', 'Apr 30 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Strasse 8', 'DE ', '63477', 'Maintal', 13280.0000000, '', 'Jul  8 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080020', 'Apr 30 2008 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 1080.0000000, '', 'Mai  7 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070037', 'Sep 30 2007 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 405.0000000, '', 'Okt 29 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070039', 'Nov  1 2007 12:00AM', 'entory AG', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 10800.0000000, '', 'Dez  5 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070040', 'Nov  1 2007 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 260.0000000, '', 'Dez 21 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070041', 'Nov  1 2007 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2420.0000000, '', 'Dez  3 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070042', 'Nov  1 2007 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 4360.0000000, '', 'Dez 28 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080021', 'Apr 30 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 2140.0000000, '', 'Mai 16 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070043', 'Nov  1 2007 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 380.0000000, '', 'Nov 27 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070044', 'Nov  1 2007 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 980.0000000, '', 'Nov 28 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070045', 'Nov 29 2007 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 4320.0000000, '', 'Dez 28 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070046', 'Dez  1 2007 12:00AM', 'entory AG', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 13137.1200000, '', 'Jan 28 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070047', 'Dez  5 2007 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 4660.0000000, '', 'Dez 21 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070048', 'Dez  5 2007 12:00AM', 'Dieffenbacher GmbH & CO Betriebssttte Pfungstadt ', 'Werner-von-Siemens-Strae 2', 'DE ', '64319', 'Pfungstadt', 40.0000000, '', 'Jan 11 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070049', 'Dez  5 2007 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 760.0000000, '', 'Dez 12 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070050', 'Dez  5 2007 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 300.0000000, '', 'Feb  7 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070051', 'Dez  5 2007 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 380.0000000, '', 'Dez 13 2007 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070052', 'Dez  5 2007 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Einsteinring 3', 'DE ', '85609', 'Mnchen', 644.0000000, '', 'Jan 14 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070053', 'Dez  5 2007 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 1140.0000000, '', 'Jul  1 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070054', 'Dez  5 2007 12:00AM', 'ACC Verlag & Services GmbH ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1080.0000000, '', 'Jan 16 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070055', 'Dez 28 2007 12:00AM', 'SR Stainless Recycling GmbH ', 'Dieselstrasse 12', 'DE ', '63456', 'Hanau', 200.0000000, '', 'Jan 11 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070056', 'Dez 28 2007 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 3200.0000000, '', 'Feb 13 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070058', 'Dez 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 3080.0000000, '', 'Feb 12 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070057', 'Dez 31 2007 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 4100.0000000, '', 'Feb 13 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080022', 'Apr 30 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 7386.4000000, '', 'Mai 19 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080023', 'Apr 30 2008 12:00AM', 'Fundacja Amerykanskiej Izby Handlowej w Polsce', 'ul. Emilii Plater 53 14p.', 'PL ', '00-113', 'Warsawa', 300.0000000, '', 'Jun 10 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070059', 'Dez 31 2007 12:00AM', 'entory AG', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 9309.6000000, '', 'Mr  6 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070060', 'Dez 31 2007 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 360.0000000, '', 'Jan 17 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080024', 'Mai 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 5178.4000000, '', 'Jun 27 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080001', 'Jan 31 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 340.0000000, '', 'Mr  4 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080002', 'Jan 31 2008 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 940.0000000, '', 'Mr 27 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080003', 'Jan 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2160.0000000, '', 'Feb 12 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080004', 'Jan 31 2008 12:00AM', 'cirquent GmbH ', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 6480.0000000, '', 'Mr 14 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080005', 'Feb  4 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 5400.0000000, '', 'Feb 28 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080006', 'Jan 31 2008 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 1180.0000000, '', 'Feb 21 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080007', 'Jan 31 2008 12:00AM', 'SR Stainless Recycling GmbH ', 'Dieselstrasse 12', 'DE ', '63456', 'Hanau', 1975.8000000, '', 'Feb 11 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20070061', 'Dez 28 2007 12:00AM', 'ACC Verlag & Services GmbH ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1200.0000000, '', 'Feb 12 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080008', 'Feb  4 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 3500.0000000, '', 'Feb 12 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080009', 'Feb 29 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41', 'BE ', '1000', 'Bruxelles', 260.0000000, '', 'Apr  1 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080010', 'Feb 29 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 3600.0000000, '', 'Mr 14 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080011', 'Feb 29 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 8280.0000000, '', 'Mr 31 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080012', 'Feb 29 2008 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 160.0000000, '', 'Jul 14 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080013', 'Feb 29 2008 12:00AM', 'American Chamber of Commerce in Poland', 'ul. Emilii Plater 53 13p.', 'PL ', '00-113', 'Warsawa', 3000.0000000, '', 'Mai  6 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080014', 'Feb 29 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 2160.0000000, '', 'Apr  1 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080015', 'Feb 29 2008 12:00AM', 'GOLD.STEIN GmbH & Co. KG', 'Beethovenstrae 65', 'DE ', '60325', 'Frankfurt am Main', 460.0000000, '', 'Mr 25 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080016', 'Apr 30 2008 12:00AM', '1st Point Consulting Services Gesellschaft fr Schulung und Systemberatung mbH ', 'Pestalozzistrasse 72a', 'DE ', '63322', 'Rdermark', 1662.5000000, '', 'Mai 28 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080025', 'Mai 31 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 1160.0000000, '', 'Jul  2 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080026', 'Mai 31 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Strasse 8', 'DE ', '63477', 'Maintal', 3900.0000000, '', 'Jul 31 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080027', 'Mai 31 2008 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 460.0000000, '', 'Mr 30 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080028', 'Mai 31 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 420.0000000, '', 'Jun 17 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080029', 'Jun 30 2008 12:00AM', '1st Point Consulting Services Gesellschaft fr Schulung und Systemberatung mbH ', 'Pestalozzistrasse 72a', 'DE ', '63322', 'Rdermark', 1172.5000000, '', 'Aug 18 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080030', 'Jun 30 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 6000.0000000, '', 'Aug  6 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080031', 'Jun 30 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 1460.0000000, '', 'Jul 24 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080032', 'Jun 30 2008 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 660.0000000, '', 'Dez 19 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080033', 'Jun 30 2008 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Einsteinring 3', 'DE ', '85609', 'Mnchen', 6531.0000000, '', 'Aug 13 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080034', 'Jun 30 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 1760.0000000, '', 'Aug  8 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080035', 'Jun 30 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Strasse 8', 'DE ', '63477', 'Maintal', 5840.0000000, '', 'Sep  6 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080036', 'Jul 18 2008 12:00AM', 'Strer Out-of-Home Media AG ', 'Strer Allee 1', 'DE ', '50999', 'Kln', 574.0000000, '', 'Aug 13 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080037', 'Aug  8 2008 12:00AM', 'cirquent GmbH ', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', -6480.0000000, '', 'Aug 14 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080038', 'Aug  1 2008 12:00AM', 'cirquent GmbH ', 'Zamdorfer Strae 120', 'DE ', '81677', 'Mnchen', 6944.6700000, '', 'Aug 14 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080039', 'Jul 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 4180.0000000, '', 'Sep 18 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080040', 'Jul 31 2008 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 900.0000000, '', 'Dez 19 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080041', 'Jul 31 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 1040.0000000, '', 'Aug 29 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080042', 'Jul 31 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 5080.0000000, '', 'Sep  3 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080044', 'Aug 31 2008 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 2691.0000000, '', 'Sep 11 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080043', 'Jul 31 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 380.0000000, '', 'Aug 23 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080045', 'Aug 31 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 2300.0000000, '', 'Okt  2 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080046', 'Aug 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 6040.0000000, '', 'Okt 13 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080047', 'Aug 31 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 3140.0000000, '', 'Okt  2 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080048', 'Aug 31 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 2060.0000000, '', 'Okt  6 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080049', 'Sep 30 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 2440.0000000, '', 'Okt 30 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080052', 'Sep 30 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 6580.0000000, '', 'Nov  4 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080050', 'Sep 30 2008 12:00AM', '1st Point Consulting Services Gesellschaft fr Schulung und Systemberatung mbH ', 'Pestalozzistrasse 72a', 'DE ', '63322', 'Rdermark', 1225.0000000, '', 'Okt 21 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080051', 'Sep 30 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 720.0000000, '', 'Nov 12 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080053', 'Sep 30 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 5660.0000000, '', 'Nov  5 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080054', 'Sep 30 2008 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 675.0000000, '', 'Nov  3 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080055', 'Sep 30 2008 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Strubberg 70', 'DE ', '60489', 'Frankfurt am Main', 500.0000000, '', 'Okt 14 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080056', 'Sep 30 2008 12:00AM', 'ACC Verlag & Services GmbH ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 0.0000000, '', 'Sep 30 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080057', 'Sep 30 2008 12:00AM', 'American Chamber of Commerce in Poland', 'ul. Emilii Plater 53 14p.', 'PL ', '00-113', 'Warsawa', 180.0000000, '', 'Dez  1 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080058', 'Okt 31 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 5000.0000000, '', 'Dez 29 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080059', 'Okt 31 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 820.0000000, '', 'Nov 28 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080060', 'Okt 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 7140.0000000, '', 'Dez  5 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080061', 'Sep 30 2008 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Strubberg 70', 'DE ', '60489', 'Frankfurt am Main', 375.2500000, '', 'Nov 13 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080062', 'Okt 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 275.4000000, '', 'Nov 11 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080063', 'Nov 30 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 1680.0000000, '', 'Apr 15 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080064', 'Nov 30 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 900.0000000, '', 'Dez 22 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080065', 'Nov 30 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2740.0000000, '', 'Dez 23 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080066', 'Nov 30 2008 12:00AM', 'avato consulting GmbH', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 6077.5000000, '', 'Feb  3 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080067', 'Nov 30 2008 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Strubberg 70', 'DE ', '60489', 'Frankfurt am Main', 957.4000000, '', 'Dez 15 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080068', 'Nov 30 2008 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 140.0000000, '', 'Dez 19 2008 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080069', 'Nov 30 2008 12:00AM', '1st Point Consulting Services Gesellschaft fr Schulung und Systemberatung mbH ', 'Pestalozzistrasse 72a', 'DE ', '63322', 'Rdermark', 945.0000000, '', 'Jan 19 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080070', 'Nov 30 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 3200.0000000, '', 'Jan 13 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080071', 'Dez 15 2008 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 12314.2000000, '', 'Jan 14 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080072', 'Dez 31 2008 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 680.0000000, '', 'Mr 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080073', 'Dez 31 2008 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 440.0000000, '', 'Jan 26 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080074', 'Dez 31 2008 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 5622.5000000, '', 'Jan 29 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080075', 'Dez 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 4700.0000000, '', 'Feb  9 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080076', 'Dez 31 2008 12:00AM', 'Fundacja Amerykanskiej Izby Handlowej w Polsce', 'ul. Emilii Plater 53 14p.', 'PL ', '00-113', 'Warsawa', 120.0000000, '', 'Jan 29 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080077', 'Dez 31 2008 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 180.0000000, '', 'Jan 30 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080078', 'Dez 31 2008 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 720.0000000, '', 'Jan 28 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20080079', 'Dez 31 2008 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', -280.0000000, '', 'Feb  9 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090001', 'Jan 31 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 800.0000000, '', 'Mr 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090002', 'Jan 31 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 120.0000000, '', 'Feb 26 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090003', 'Jan 31 2009 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 100.0000000, '', 'Mr  2 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090004', 'Jan 31 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9685.0000000, '', 'Mr  3 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090007', 'Jan 31 2009 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Strubberg 70', 'DE ', '60489', 'Frankfurt am Main', 60.0000000, '', 'Feb 19 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090005', 'Jan 31 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2600.0000000, '', 'Apr 14 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090006', 'Jan 31 2009 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 960.0000000, '', 'Mr  2 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090008', 'Feb 18 2009 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 920.0000000, '', 'Mr  6 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090009', 'Feb 18 2009 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 2369.0000000, '', 'Mr 16 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090010', 'Feb 24 2009 12:00AM', 'Ghling & Kaufmann Automobile GmbH', 'Niederhofheimer Strasse 59', 'DE ', '65719', 'Hofheim am Taunus', 31722.6900000, '', 'Feb 24 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090011', 'Feb 28 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 10725.0000000, '', 'Mr 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090012', 'Feb 28 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2620.0000000, '', 'Apr 28 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090013', 'Feb 28 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 390.0000000, '', 'Jul 21 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090014', 'Feb 28 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 320.0000000, '', 'Apr  6 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090015', 'Feb 28 2009 12:00AM', '1st Point Consulting Services Gesellschaft fr Schulung und Systemberatung mbH ', 'Pestalozzistrasse 72a', 'DE ', '63322', 'Rdermark', 455.0000000, '', 'Mr 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090016', 'Mr 31 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9685.0000000, '', 'Apr 30 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090017', 'Mr 31 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 580.0000000, '', 'Mai  5 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090018', 'Mr 31 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 3060.0000000, '', 'Jun  3 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090019', 'Mr 31 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 260.0000000, '', 'Mai  5 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090020', 'Mr 31 2009 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Strubberg 70', 'DE ', '60489', 'Frankfurt am Main', 200.0000000, '', 'Apr  8 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090021', 'Mr 31 2009 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 880.0000000, '', 'Apr 27 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090022', 'Mr 31 2009 12:00AM', 'Dieffenbacher GmbH & CO Betriebssttte Pfungstadt ', 'Werner-von-Siemens-Strae 2', 'DE ', '64319', 'Pfungstadt', 160.0000000, '', 'Apr 22 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090023', 'Mr 31 2009 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 2227.5000000, '', 'Mai  4 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090024', 'Mr 31 2009 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V. ', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 1520.0000000, '', 'Mai 18 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090025', 'Mr 31 2009 12:00AM', 'HWT Wassertechnische Anlagen GmbH', 'Am Dornbusch 15', 'DE ', '64390', 'Erzhausen', 240.0000000, '', 'Apr 29 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090026', 'Apr 20 2009 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 6693.0000000, '', 'Mai  5 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090027', 'Apr 30 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 14397.5000000, '', 'Jun  2 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090028', 'Apr 30 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 80.0000000, '', 'Jul 21 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090029', 'Apr 30 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2760.0000000, '', 'Jun  3 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090030', 'Apr 30 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 460.0000000, '', 'Mai 27 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090031', 'Apr 30 2009 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V. ', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 1260.0000000, '', 'Sep 11 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090032', 'Mai 31 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 80.0000000, '', 'Jun 30 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090033', 'Mai 31 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 4060.0000000, '', 'Jul 28 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090034', 'Mai 31 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 10790.0000000, '', 'Jun 30 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090035', 'Mai 31 2009 12:00AM', 'European Central Bank', 'Kaiserstrae 29', 'DE ', '60311', 'Frankfurt am Main', 1720.0000000, '', 'Jun  9 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090036', 'Mai 31 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 500.0000000, '', 'Jun 29 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090037', 'Mai 31 2009 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 520.0000000, '', 'Jun 29 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090038', 'Jun 30 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 320.0000000, '', 'Jul  7 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090039', 'Jun 30 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9255.0000000, '', 'Jul 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090040', 'Jun 30 2009 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 500.0000000, '', 'Okt 26 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090041', 'Jun 30 2009 12:00AM', 'Fundacja Amerykanskiej Izby Handlowej w Polsce', 'ul. Emilii Plater 53 14p.', 'PL ', '00-113', 'Warsawa', 120.0000000, '', 'Jul  7 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090042', 'Jun 30 2009 12:00AM', 'European Central Bank', 'Kaiserstrae 29', 'DE ', '60311', 'Frankfurt am Main', 5680.0000000, '', 'Jul 16 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090043', 'Jun 30 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 320.0000000, '', 'Jul 23 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090044', 'Jun 30 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 4170.8800000, '', 'Jul 28 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090045', 'Jun 30 2009 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 760.0000000, '', 'Jul 28 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090046', 'Jun 30 2009 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1935.0000000, '', 'Aug 17 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090048', 'Jul 31 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 140.0000000, '', 'Sep  1 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090049', 'Jul 31 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2440.0000000, '', 'Sep  3 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090050', 'Jul 31 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 7345.0000000, '', 'Aug 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090047', 'Jul 23 2009 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 3312.0000000, '', 'Aug  4 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090051', 'Jul 31 2009 12:00AM', 'European Central Bank', 'Kaiserstrae 29', 'DE ', '60311', 'Frankfurt am Main', 2480.0000000, '', 'Aug 18 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090052', 'Jul 31 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 1433.6000000, '', 'Aug 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090053', 'Jul 31 2009 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 4462.0000000, '', 'Aug 26 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090054', 'Aug 31 2009 12:00AM', '1st Point Consulting Services Gesellschaft fr Schulung und Systemberatung mbH ', 'Pestalozzistrasse 72a', 'DE ', '63322', 'Rdermark', 227.5000000, '', 'Sep  8 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090055', 'Aug 31 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 380.0000000, '', 'Okt  5 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090056', 'Aug 31 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2800.0000000, '', 'Sep 17 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090057', 'Aug 31 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 12787.5000000, '', 'Okt  1 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090058', 'Aug 31 2009 12:00AM', 'European Central Bank', 'Kaiserstrae 29', 'DE ', '60311', 'Frankfurt am Main', 2960.0000000, '', 'Sep 28 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090059', 'Aug 31 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 147.2000000, '', 'Okt  5 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090060', 'Aug 31 2009 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V. ', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', -890.0000000, '', 'Aug 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090061', 'Aug 31 2009 12:00AM', 'Arbeitgeberverband Leuchten- und Zubehr-Industrie e.V.', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 890.0000000, '', 'Sep 11 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090062', 'Sep 30 2009 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 100.0000000, '', 'Nov  3 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090063', 'Sep 30 2009 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 400.0000000, '', 'Feb 18 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090064', 'Sep 30 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2980.0000000, '', 'Nov  3 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090065', 'Sep 30 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 12902.5000000, '', 'Nov  3 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090066', 'Sep 30 2009 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 3200.0000000, '', 'Okt  7 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090067', 'Sep 30 2009 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 317.5000000, '', 'Okt 30 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090068', 'Sep 30 2009 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V. ', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 400.0000000, '', 'Okt 16 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090069', 'Sep 30 2009 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 585.0000000, '', 'Jun 18 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090070', 'Okt 31 2009 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 640.0000000, '', 'Dez  9 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090071', 'Okt 31 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 3778.8200000, '', 'Nov 25 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090072', 'Okt 31 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9766.2500000, '', 'Dez  1 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090074', 'Nov 30 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 11001.2500000, '', 'Dez 30 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090073', 'Okt 31 2009 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 520.0000000, '', 'Nov 30 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090075', 'Nov 30 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 3140.0000000, '', 'Feb  9 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090076', 'Nov 30 2009 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 1435.0000000, '', 'Dez 22 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090077', 'Dez 19 2009 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 4646.0000000, '', 'Jan  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090078', 'Dez 31 2009 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 160.0000000, '', 'Feb  3 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090079', 'Dez 31 2009 12:00AM', 'American Chamber of Commerce in France ', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 400.0000000, '', 'Feb 18 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090080', 'Dez 31 2009 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 3080.0000000, '', 'Feb  9 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090081', 'Dez 31 2009 12:00AM', 'Fundacja Amerykanskiej Izby Handlowej w Polsce', 'ul. Emilii Plater 53 14p.', 'PL ', '00-113', 'Warsawa', 260.0000000, '', 'Feb  3 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090082', 'Dez 31 2009 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 8403.7500000, '', 'Feb  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090083', 'Dez 31 2009 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 10657.5000000, '', 'Jan 29 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090084', 'Dez 31 2009 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V. ', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', -260.0000000, '', 'Dez 31 2009 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090085', 'Dez 31 2009 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 380.0000000, '', 'Feb  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20090086', 'Dez 31 2009 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V. ', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 200.0000000, '', 'Jan 29 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100001', 'Jan 31 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 300.0000000, '', 'Mr  3 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100002', 'Jan 31 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2660.0000000, '', 'Apr 13 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100003', 'Jan 31 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 12985.0000000, '', 'Mr  3 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100004', 'Jan 31 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 10622.5000000, '', 'Feb 23 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100005', 'Jan 31 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 300.0000000, '', 'Mr  5 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100006', 'Jan 31 2010 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 230.0000000, '', 'Mr  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100007', 'Feb 28 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 580.0000000, '', 'Apr  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100008', 'Feb 28 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1780.0000000, '', 'Apr 13 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100009', 'Feb 28 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 7505.0000000, '', 'Mr 31 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100010', 'Feb 28 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 13440.0000000, '', 'Mr 23 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100017', 'Mr 31 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 100.0000000, '', 'Mai  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100012', 'Mr 31 2010 12:00AM', 'American Chamber of Commerce in France ', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 280.0000000, '', 'Jun  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100013', 'Mr 31 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 3420.0000000, '', 'Apr 23 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100014', 'Mr 31 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 6987.5000000, '', 'Mai  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100015', 'Mr 31 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 12880.0000000, '', 'Apr 27 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100026', 'Apr 30 2010 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V. ', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 20.0000000, '', 'Jan  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100011', 'Mr 31 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 2140.0000000, '', 'Mai  5 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100018', 'Apr 30 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 260.0000000, '', 'Jun  2 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100019', 'Apr 30 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 3100.0000000, '', 'Jun 21 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100020', 'Apr 30 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 4615.0000000, '', 'Jun  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100021', 'Apr 30 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 8960.0000000, '', 'Mai 14 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100022', 'Apr 30 2010 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1125.0000000, '', 'Mai 28 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100023', 'Apr 30 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 280.0000000, '', 'Jun  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100024', 'Apr 30 2010 12:00AM', 'Gesellschaft fr Netzwerk- und Systemintegration mbH', 'Robert-Bosch-Str. 8', 'DE ', '63477', 'Maintal', 320.0000000, '', 'Jun  7 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100025', 'Apr 30 2010 12:00AM', 'SR Stainless Recycling GmbH ', 'Dieselstrasse 12', 'DE ', '63456', 'Hanau', 592.0000000, '', 'Mai 10 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100027', 'Mai 31 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 140.0000000, '', 'Jul  2 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100028', 'Mai 31 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 4900.0000000, '', 'Jul  6 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100029', 'Mai 31 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9425.0000000, '', 'Jul  2 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100030', 'Mai 31 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 10220.0000000, '', 'Jun 23 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100016', 'Mai 31 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 300.0000000, '', 'Jul  5 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100031', 'Jun 24 2010 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1058.0000000, '', 'Jul 15 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100032', 'Jun 30 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 300.0000000, '', 'Aug  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100033', 'Jun 30 2010 12:00AM', 'American Chamber of Commerce in France ', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 260.0000000, '', 'Apr  8 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100034', 'Jun 30 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 700.0000000, '', 'Aug  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100035', 'Jun 30 2010 12:00AM', 'Fundacja Amerykanskiej Izby Handlowej w Polsce', 'ul. Emilii Plater 53 14p.', 'PL ', '00-113', 'Warsawa', 140.0000000, '', 'Jul 26 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100036', 'Jun 30 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9457.5000000, '', 'Aug  2 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100037', 'Jun 30 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 12180.0000000, '', 'Jul 21 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100038', 'Jun 30 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 0.0000000, '', 'Aug  2 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100039', 'Jun 30 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 100.0000000, '', 'Jun 30 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100040', 'Jul 31 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 80.0000000, '', 'Sep  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100041', 'Jul 31 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2140.0000000, '', 'Aug 16 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100042', 'Jul 31 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9742.5000000, '', 'Sep  2 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100043', 'Jul 31 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 7840.0000000, '', 'Aug 16 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100044', 'Jul 31 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 160.0000000, '', 'Aug 31 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100045', 'Jul 31 2010 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 414.0000000, '', 'Aug 16 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100046', 'Aug 31 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 860.0000000, '', 'Okt  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100047', 'Aug 31 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2820.0000000, '', 'Okt 15 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100048', 'Aug 31 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 11765.0000000, '', 'Okt  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100049', 'Aug 31 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 9940.0000000, '', 'Okt 25 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100050', 'Aug 31 2010 12:00AM', 'CompuSafe Data Systems AG ', 'Oetztaler Str. 18', 'DE ', '81373', 'Mnchen', 30000.0000000, '', 'Sep 30 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100051', 'Aug 31 2010 12:00AM', 'European Central Bank ', 'Kaiserstrae 29', 'DE ', '60311', 'Frankfurt am Main', 480.0000000, '', 'Sep 13 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100052', 'Aug 31 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 140.0000000, '', 'Okt  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100053', 'Sep 30 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 1120.0000000, '', 'Aug  5 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100054', 'Sep 30 2010 12:00AM', 'American Chamber of Commerce in France ', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 600.0000000, '', 'Apr  8 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100055', 'Sep 30 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2800.0000000, '', 'Nov  4 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100056', 'Sep 30 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 10042.5000000, '', 'Nov  2 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100057', 'Sep 30 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 11130.0000000, '', 'Okt 30 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100058', 'Sep 30 2010 12:00AM', 'CompuSafe Data Systems AG ', 'Oetztaler Str. 18', 'DE ', '81373', 'Mnchen', 30000.0000000, '', 'Nov  3 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100059', 'Sep 30 2010 12:00AM', 'GIB Gesellschaft fr Immobilienbewertung mbH ', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 3586.0000000, '', 'Nov  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100060', 'Sep 30 2010 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V. ', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 120.0000000, '', 'Jan  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100061', 'Sep 30 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 880.0000000, '', 'Nov  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100062', 'Sep 30 2010 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V. ', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 20.0000000, '', 'Okt  5 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100063', 'Okt 31 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 2520.0000000, '', 'Dez  6 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100064', 'Okt 31 2010 12:00AM', 'CompuSafe Data Systems AG ', 'Oetztaler Str. 18', 'DE ', '81373', 'Mnchen', 30000.0000000, '', 'Dez  6 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100065', 'Okt 31 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 13552.5000000, '', 'Dez  2 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100066', 'Okt 31 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 9520.0000000, '', 'Nov 24 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100067', 'Okt 31 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 240.0000000, '', 'Dez  1 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100068', 'Okt 31 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1869.5000000, '', 'Nov 30 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100069', 'Okt 31 2010 12:00AM', 'GIB Gesellschaft fr Immobilienbewertung mbH ', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 644.0000000, '', 'Okt 31 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100070', 'Okt 31 2010 12:00AM', 'SR Stainless Recycling GmbH ', 'Dieselstrasse 12', 'DE ', '63456', 'Hanau', 400.0000000, '', 'Jan  5 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100071', 'Nov 30 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 120.0000000, '', 'Jan  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100072', 'Nov 30 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 5721.0300000, '', 'Jan 21 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100073', 'Nov 30 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 11765.0000000, '', 'Jan  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100074', 'Nov 30 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 7245.0000000, '', 'Dez 21 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100075', 'Nov 30 2010 12:00AM', 'CompuSafe Data Systems AG', 'Oetztaler Str. 18', 'DE ', '81373', 'Mnchen', 30000.0000000, '', 'Dez 31 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100076', 'Nov 30 2010 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 420.0000000, '', 'Dez 17 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100077', 'Dez 31 2010 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 100.0000000, '', 'Feb  1 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100078', 'Dez 31 2010 12:00AM', 'American Chamber of Commerce in France ', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 220.0000000, '', 'Apr  8 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100079', 'Dez 31 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2882.8000000, '', 'Jan 21 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100080', 'Dez 31 2010 12:00AM', 'Fundacja Amerykanskiej Izby Handlowej w Polsce', 'ul. Emilii Plater 53 14p.', 'PL ', '00-113', 'Warsawa', 60.0000000, '', 'Jan 17 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100081', 'Dez 31 2010 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 7345.0000000, '', 'Jan 31 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100082', 'Dez 31 2010 12:00AM', 'CBC Consult GmbH ', 'Kaiserstrasse 44', 'DE ', '60329', 'Frankfurt am Main', 4480.0000000, '', 'Jan 26 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100083', 'Dez 31 2010 12:00AM', 'CompuSafe Data Systems AG', 'Oetztaler Str. 18', 'DE ', '81373', 'Mnchen', -30000.0000000, '', 'Dez 31 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100084', 'Dez 31 2010 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V. ', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 440.0000000, '', 'Jan  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100085', 'Dez 31 2010 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1395.0000000, '', 'Jan 28 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100086', 'Dez 31 2010 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 1540.0000000, '', 'Jan 26 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110001', 'Jan 31 2011 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 392.8000000, '', 'Apr  5 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110002', 'Jan 31 2011 12:00AM', 'avato consulting GmbH', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 13125.0000000, '', 'Mr  4 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110003', 'Jan 31 2011 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 2800.0000000, '', 'Feb 24 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20100087', 'Dez 31 2010 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', -1893.6000000, '', 'Dez 31 2010 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110004', 'Feb 13 2011 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 2392.0000000, '', 'Feb 22 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110005', 'Feb 28 2011 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 1180.0000000, '', 'Apr  7 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110006', 'Feb 28 2011 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2400.0000000, '', 'Apr  5 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110007', 'Feb 28 2011 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 8067.5000000, '', 'Apr  1 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110008', 'Feb 28 2011 12:00AM', 'Hays AG ', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 7240.0000000, '', 'Apr  1 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110009', 'Feb 28 2011 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 920.0000000, '', 'Mr 25 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110010', 'Mr 31 2011 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 1040.0000000, '', 'Mai  4 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110011', 'Mr 31 2011 12:00AM', 'American Chamber of Commerce in France ', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 280.0000000, '', 'Jul 28 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110012', 'Mr 31 2011 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2680.0000000, '', 'Mai 23 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110013', 'Mr 31 2011 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 11655.0000000, '', 'Mai  2 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110014', 'Mr 31 2011 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V. ', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 160.0000000, '', 'Jun  7 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110015', 'Mr 31 2011 12:00AM', 'Hays AG ', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 8760.0000000, '', 'Apr 28 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110016', 'Mr 31 2011 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 1460.0000000, '', 'Apr 21 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110017', 'Mr 31 2011 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V. ', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 40.0000000, '', 'Mai 19 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110018', 'Apr  1 2011 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Str. 18', 'DE ', '80333', 'Mnchen', 4163.0000000, '', 'Apr 29 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110019', 'Apr 30 2011 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 300.0000000, '', 'Aug  5 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110020', 'Apr 30 2011 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1820.0000000, '', 'Mai 23 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110021', 'Apr 30 2011 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 14787.5000000, '', 'Jun  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110022', 'Apr 30 2011 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 4560.0000000, '', 'Mai 31 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110023', 'Apr 30 2011 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 240.0000000, '', 'Mai 25 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110024', 'Apr 30 2011 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Str. 18', 'DE ', '80333', 'Mnchen', 1472.0000000, '', 'Mai 19 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110025', 'Mai 31 2011 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 360.0000000, '', 'Jul  4 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110026', 'Mai 31 2011 12:00AM', 'American Chamber of Commerce  in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 2260.0000000, '', 'Jun 20 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110027', 'Mai 31 2011 12:00AM', 'avato consulting GmbH ', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 10640.0000000, '', 'Jul  1 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110028', 'Mai 31 2011 12:00AM', 'GIB Gesellschaft fr Immobilienbewertung mbH ', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 184.0000000, '', 'Jul 12 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110029', 'Mai 31 2011 12:00AM', 'Hays AG ', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 9800.0000000, '', 'Jul  6 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110030', 'Mai 31 2011 12:00AM', 'Jnger+Grter GmbH ', 'Robert-Bosch-Strae 1', 'DE ', '68723', 'Schwetzingen', 1211.2500000, '', 'Jun 29 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110031', 'Mai 31 2011 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Briener Strasse 18', 'DE ', '80333', 'Mnchen', 1840.0000000, '', 'Jun 10 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110032', 'Mai 31 2011 12:00AM', 'SR Stainless Recycling GmbH', 'Dieselstrasse 12', 'DE ', '63456', 'Hanau', 752.0500000, '', 'Aug 18 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110033', 'Mai 31 2011 12:00AM', 'Swiss-American Chamber of Commerce ', 'Talacker 41', 'CH ', '8001', 'Zurich', 240.0000000, '', 'Jun 24 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110034', 'Jun 30 2011 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 520.0000000, '', 'Aug  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110035', 'Jun 30 2011 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 180.0000000, '', 'Feb  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110036', 'Jun 30 2011 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1680.0000000, '', 'Nov 15 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110037', 'Jun 30 2011 12:00AM', 'Fundacja Amerykanskiej Izby Handlowej w Polsce', 'ul. Emilii Plater 53 14p.', 'PL ', '00-113', 'Warsawa', 100.0000000, '', 'Jul 14 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110038', 'Jun 30 2011 12:00AM', 'avato consulting AG', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 10465.0000000, '', 'Aug  1 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110039', 'Jun 30 2011 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 80.0000000, '', 'Jul  6 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110040', 'Jun 30 2011 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 6020.0000000, '', 'Jun  7 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110041', 'Jun 30 2011 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 40.0000000, '', 'Jul 29 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110042', 'Jun 30 2011 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V.', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 160.0000000, '', 'Jul 18 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110043', 'Jul 31 2011 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 540.0000000, '', 'Sep  2 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110044', 'Jul 31 2011 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1520.0000000, '', 'Aug  8 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110045', 'Jul 31 2011 12:00AM', 'avato consulting AG', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9730.0000000, '', 'Sep  2 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110046', 'Jul 31 2011 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 4520.0000000, '', 'Aug 30 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110047', 'Jul 31 2011 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 337.5000000, '', 'Aug 26 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110048', 'Jul 31 2011 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 580.0000000, '', 'Aug 24 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110049', 'Jul 31 2011 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH ', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 2093.0000000, '', 'Aug 18 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110050', 'Aug 31 2011 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 60.0000000, '', 'Nov 15 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110051', 'Aug 31 2011 12:00AM', 'American Chamber of Commerce in Germany e.V. ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1220.0000000, '', 'Nov 15 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110052', 'Aug 31 2011 12:00AM', 'avato consulting AG', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 13685.0000000, '', 'Okt  4 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110053', 'Aug 31 2011 12:00AM', 'DB Private Equity GmbH', 'Zeppelinstrasse 4-8', 'DE ', '50667', 'Kln', 6555.0000000, '', 'Sep 20 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110057', 'Sep 30 2011 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Frankfurt am Main', 200.0000000, '', 'Okt 26 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110055', 'Aug 31 2011 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 4260.0000000, '', 'Okt  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110056', 'Sep 30 2011 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V. ', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 160.0000000, '', 'Okt 19 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110054', 'Aug 31 2011 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 900.0000000, '', 'Sep 27 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110058', 'Sep 30 2011 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 300.0000000, '', 'Nov 15 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110059', 'Sep 30 2011 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 280.0000000, '', 'Feb  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110060', 'Sep 30 2011 12:00AM', 'American Chamber of Commerce in Germany e.V. ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1120.0000000, '', 'Nov 15 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110061', 'Sep 30 2011 12:00AM', 'avato consulting AG', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 8575.0000000, '', 'Nov  3 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110062', 'Sep 30 2011 12:00AM', 'BRAND EDV-Training & IT', 'Ostbahnhofstr. 13', 'DE ', '60314', 'Frankfurt am Main', 3000.0000000, '', 'Okt 10 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110063', 'Sep 30 2011 12:00AM', 'DB Private Equity GmbH ', 'Zeppelinstrasse 4-8', 'DE ', '50667', 'Kln', 2446.2500000, '', 'Okt 21 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110064', 'Sep 30 2011 12:00AM', 'GIB Gesellschaft fr Immobilienbewertung mbH ', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 40.0000000, '', 'Okt 31 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110065', 'Sep 30 2011 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 220.0000000, '', 'Okt  5 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110066', 'Sep 30 2011 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 4980.0000000, '', 'Nov  2 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110068', 'Sep 30 2011 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 4490.5500000, '', 'Nov  9 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110067', 'Sep 30 2011 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 2745.0000000, '', 'Okt 28 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110069', 'Okt 31 2011 12:00AM', 'American Chamber of Commerce in Belgium ', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 2640.0000000, '', 'Dez  2 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110070', 'Okt 31 2011 12:00AM', 'American Chamber of Commerce in Germany e.V. ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1420.0000000, '', 'Jan 12 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110071', 'Okt 31 2011 12:00AM', 'avato consulting AG', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 9065.0000000, '', 'Dez  2 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110072', 'Okt 31 2011 12:00AM', 'DB Private Equity GmbH', 'Zeppelinstrasse 4-8', 'DE ', '50667', 'Kln', 4702.5000000, '', 'Dez  2 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110073', 'Okt 31 2011 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 5355.0000000, '', 'Dez  5 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110074', 'Okt 31 2011 12:00AM', 'SR Stainless Recycling GmbH', 'Dieselstrasse 12', 'DE ', '63456', 'Hanau', 560.0000000, '', 'Nov 18 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110075', 'Okt 31 2011 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 640.0000000, '', 'Nov 28 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110076', 'Okt 31 2011 12:00AM', 'GIB Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 736.0000000, '', 'Nov 28 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110077', 'Okt 31 2011 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 3933.0000000, '', 'Nov 16 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110078', 'Okt 31 2011 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 9132.5700000, '', 'Dez 16 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110079', 'Okt 31 2011 12:00AM', 'American Chamber of Commerce in Germany e.V. ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 289.5000000, '', 'Nov 15 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110080', 'Nov 30 2011 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Commerce 39-41 Handelsstraat', 'BE ', '1000', 'Bruxelles', 480.0000000, '', 'Dez 16 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110081', 'Nov 30 2011 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 260.0000000, '', 'Dez  5 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110082', 'Nov 30 2011 12:00AM', 'avato consulting AG', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 11025.0000000, '', 'Dez 30 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110083', 'Nov 30 2011 12:00AM', 'BRAND EDV-Training & IT', 'Ostbahnhofstr. 13', 'DE ', '60314', 'Frankfurt am Main', 2700.0000000, '', 'Dez  7 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110084', 'Nov 30 2011 12:00AM', 'DB Private Equity GmbH', 'Zeppelinstrasse 4-8', 'DE ', '50667', 'Kln', 5510.0000000, '', 'Dez 20 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110085', 'Nov 30 2011 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 9440.0000000, '', 'Jan  6 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110086', 'Nov 30 2011 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 12240.0000000, '', 'Dez 15 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110087', 'Nov 30 2011 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 300.0000000, '', 'Dez  8 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110088', 'Nov 30 2011 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 9180.0000000, '', 'Jan  4 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110089', 'Nov 30 2011 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 2208.0000000, '', 'Dez 15 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110091', 'Dez 13 2011 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 4365.0000000, '', 'Jan 13 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110092', 'Dez 31 2011 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 600.0000000, '', 'Feb  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110093', 'Dez 31 2011 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1380.0000000, '', 'Jan 12 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110094', 'Dez 31 2011 12:00AM', 'avato consulting AG', 'Am neuen Berg 17', 'DE ', '63755', 'Alzenau', 11130.0000000, '', 'Jan 27 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110095', 'Dez 31 2011 12:00AM', 'DIGEL AG', 'Calwer Strasse 81', 'DE ', '72202', 'Nagold', 1015.0000000, '', 'Jan 10 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110096', 'Dez 31 2011 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 3980.0000000, '', 'Dez 25 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110097', 'Dez 31 2011 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 9945.0000000, '', 'Jan 12 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110098', 'Dez 31 2011 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V.', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 420.0000000, '', 'Dez 29 2011 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110090', 'Dez 31 2011 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 10710.0000000, '', 'Feb  1 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110099', 'Dez 31 2011 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 160.0000000, '', 'Jan 13 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20110100', 'Dez 31 2011 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 5152.0000000, '', 'Jan 17 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120001', 'Jan 12 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 414.0000000, '', 'Jan 17 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120002', 'Jan 31 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 260.0000000, '', 'Apr 17 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120003', 'Jan 31 2012 12:00AM', 'American Chamber of Commerce in Germany e.V. ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 880.0000000, '', 'Feb  7 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120004', 'Jan 31 2012 12:00AM', 'avato consulting AG  ', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 11200.0000000, '', 'Mr  5 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120005', 'Jan 31 2012 12:00AM', 'European Central Bank', 'Kaiserstrae 29', 'DE ', '60311', 'Frankfurt am Main', 640.0000000, '', 'Mr 12 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120006', 'Jan 31 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 5160.0000000, '', 'Mr  1 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120007', 'Jan 31 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 13770.0000000, '', 'Feb 16 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120008', 'Jan 31 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 140.0000000, '', 'Feb 21 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120009', 'Jan 31 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 1817.0000000, '', 'Mr  1 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120010', 'Feb 29 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 900.0000000, '', 'Apr  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120011', 'Feb 29 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 220.0000000, '', 'Mr 13 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120012', 'Feb 29 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 14735.0000000, '', 'Apr  2 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120013', 'Feb 29 2012 12:00AM', 'European Central Bank', 'Kaiserstrae 29', 'DE ', '60311', 'Frankfurt am Main', 2160.0000000, '', 'Mr 12 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120014', 'Feb 29 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 4580.0000000, '', 'Apr  4 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120015', 'Feb 29 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 3060.0000000, '', 'Mai 30 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120016', 'Feb 29 2012 12:00AM', 'Scala Management Consulting GmbH Partner fr Strategie, Vernderung und Innovation', 'Stadttor 1', 'DE ', '40219', 'Dsseldorf', 380.0000000, '', 'Mr  6 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120017', 'Feb 29 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 1080.0000000, '', 'Mr 27 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120018', 'Feb 29 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 12240.0000000, '', 'Mr 21 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120019', 'Feb 29 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 3381.0000000, '', 'Mr 27 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120020', 'Mr 31 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 460.0000000, '', 'Mai  2 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120021', 'Mr 31 2012 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 720.0000000, '', 'Sep  6 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120022', 'Mr 31 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 140.0000000, '', 'Apr 10 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120023', 'Mr 31 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 13422.5000000, '', 'Mai  2 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120024', 'Mr 31 2012 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 240.0000000, '', 'Apr  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120025', 'Mr 31 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 3600.0000000, '', 'Mai  4 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120026', 'Mr 31 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 6120.0000000, '', 'Mai 30 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120027', 'Mr 31 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 240.0000000, '', 'Apr 25 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120028', 'Mr 31 2012 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V.', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 700.0000000, '', 'Apr  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120029', 'Mr 31 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 4140.0000000, '', 'Apr 25 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120031', 'Apr 30 2012 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 630.0000000, '', 'Jun 29 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120030', 'Mr 31 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 13005.0000000, '', 'Mai 30 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120032', 'Apr 30 2012 12:00AM', 'Advanced UniByte GmbH', 'Birnenweg 15', 'DE ', '72766', 'Reutlingen', 1213.5000000, '', 'Jun  1 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120033', 'Apr 30 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 40.0000000, '', 'Mai 31 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120034', 'Apr 30 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 360.0000000, '', 'Mai  7 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120035', 'Apr 30 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 7665.0000000, '', 'Jun  4 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120036', 'Apr 30 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 1880.0000000, '', 'Jun  1 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120037', 'Apr 30 2012 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 570.0000000, '', 'Mai 25 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120038', 'Apr 30 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 3450.0000000, '', 'Mai 23 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120039', 'Apr 30 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 860.0000000, '', 'Mai 30 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120040', 'Apr 30 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 11475.0000000, '', 'Jun 12 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120041', 'Mai 31 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 240.0000000, '', 'Jun 18 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120042', 'Mai 31 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 280.0000000, '', 'Jun 15 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120043', 'Mai 31 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 11287.5000000, '', 'Jul  2 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120044', 'Mai 31 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 2880.0000000, '', 'Jul  9 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120045', 'Mai 31 2012 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 40.0000000, '', 'Jun 27 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120046', 'Mai 31 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 460.0000000, '', 'Jun 27 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120047', 'Mai 31 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 552.0000000, '', 'Jun 28 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120048', 'Mai 31 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 11475.0000000, '', 'Jul 16 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120049', 'Jun 30 2012 12:00AM', 'ACC Verlag & Services GmbH  ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1680.0000000, '', 'Jul 19 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120050', 'Jun 30 2012 12:00AM', 'American Chamber of Commerce in France', 'Boulevard Haussmann 156', 'FR ', '75008', 'Paris', 100.0000000, '', 'Sep  6 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120051', 'Jun 30 2012 12:00AM', 'American Chamber of Commerce in Germany e.V. ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 100.0000000, '', 'Jul 19 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120052', 'Jun 30 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 14017.5000000, '', 'Aug  2 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120053', 'Jun 30 2012 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 140.0000000, '', 'Jul  6 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120054', 'Jun 30 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 2900.0000000, '', 'Aug  7 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120055', 'Jun 30 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 10710.0000000, '', 'Aug 17 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120056', 'Jun 30 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 320.0000000, '', 'Aug  1 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120057', 'Jun 30 2012 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V.', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 646.0400000, '', 'Jul  6 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120058', 'Jul 31 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 1794.0000000, '', 'Aug 30 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120059', 'Jul 31 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 200.0000000, '', 'Aug  7 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120060', 'Jul 31 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 5845.0000000, '', 'Sep  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120061', 'Jul 31 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 3640.0000000, '', 'Sep  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120062', 'Jul 31 2012 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 425.0000000, '', 'Aug 20 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120063', 'Jul 31 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 300.0000000, '', 'Aug 29 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120064', 'Jul 31 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 12240.0000000, '', 'Aug 16 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120065', 'Jul 31 2012 12:00AM', 'ACC Verlag & Services GmbH', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 580.0000000, '', 'Aug  6 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120066', 'Aug  6 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 5355.0000000, '', 'Sep  7 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120067', 'Aug 31 2012 12:00AM', 'ACC Verlag & Services GmbH  ', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 240.0000000, '', 'Sep 12 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120068', 'Aug 31 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 400.0000000, '', 'Okt  1 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120069', 'Aug 31 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 600.0000000, '', 'Sep 11 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120070', 'Aug 31 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 13090.0000000, '', 'Okt  2 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120071', 'Aug 31 2012 12:00AM', 'Deutsche Bank (Suisse) S.A.  GT Retail Production', 'Case Postale 1416', 'CH ', '1211', 'Geneva 1', 1098.5000000, '', 'Okt  2 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120072', 'Aug 31 2012 12:00AM', 'DIGEL AG', 'Calwer Strasse 81', 'DE ', '72202', 'Nagold', 165.0000000, '', 'Sep 19 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120073', 'Aug 31 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 1880.0000000, '', 'Okt  4 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120074', 'Aug 31 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 12240.0000000, '', 'Okt  5 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120075', 'Aug 31 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH ', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 1288.0000000, '', 'Sep 25 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120076', 'Aug 31 2012 12:00AM', 'Swiss Post Solutions GmbH Division Document Output', 'Kirchheimer Strae 177', 'DE ', '73265', 'Dettingen u. Teck', 1611.0000000, '', 'Nov  9 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120077', 'Aug 31 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 60.0000000, '', 'Sep 24 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120078', 'Aug 31 2012 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 950.0000000, '', 'Okt  1 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120079', 'Sep  4 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 9945.0000000, '', 'Okt  5 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120080', 'Sep 30 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 2260.0000000, '', 'Apr  3 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120081', 'Sep 30 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 420.0000000, '', 'Okt 18 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120082', 'Sep 30 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 12425.0000000, '', 'Nov  2 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120083', 'Sep 30 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 12240.0000000, '', 'Nov 13 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120084', 'Sep 30 2012 12:00AM', 'Verband Papier, Pappe und Kunststoff verarbeitende Unternehmen Mitte e.V.', 'Kleiner Biergrund 18', 'DE ', '63065', 'Offenbach am Main', 120.0000000, '', 'Okt  5 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120085', 'Sep 30 2012 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 1282.5000000, '', 'Okt 26 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120086', 'Sep 30 2012 12:00AM', 'Lenroxx GmbH', 'Speyerer Strasse 4', 'DE ', '69115', 'Heidelberg', 3060.0000000, '', 'Nov 13 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120087', 'Okt  6 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', -1260.0000000, '', 'Okt  6 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120088', 'Okt 31 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 360.0000000, '', 'Nov  7 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120089', 'Okt 31 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 4672.5000000, '', 'Dez  3 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120090', 'Okt 31 2012 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 7000.0000000, '', 'Dez  4 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120091', 'Okt 31 2012 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 3372.5000000, '', 'Nov 26 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120092', 'Okt 31 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 60.0000000, '', 'Nov 22 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120093', 'Nov 30 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 380.0000000, '', 'Jan  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120094', 'Nov 30 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 200.0000000, '', 'Dez 21 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120095', 'Nov 30 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 5810.0000000, '', 'Jan  3 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120096', 'Nov 30 2012 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 12160.0000000, '', 'Dez 27 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120097', 'Nov 30 2012 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 180.0000000, '', 'Dez 24 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120098', 'Nov 30 2012 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 1282.5000000, '', 'Dez 27 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120099', 'Dez 31 2012 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 1760.0000000, '', 'Jan 24 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120100', 'Dez 31 2012 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 140.0000000, '', 'Jan 16 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120101', 'Dez 31 2012 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 2870.0000000, '', 'Jan 25 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120102', 'Dez 31 2012 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 10360.0000000, '', 'Feb  4 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120103', 'Dez 31 2012 12:00AM', 'Hauptverband Papier- und Kunststoffverarbeitung (HPV) e.V.', 'Chausseestrae 22', 'DE ', '10115', 'Berlin', 300.0000000, '', 'Dez 28 2012 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120104', 'Dez 31 2012 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 3102.5000000, '', 'Jan 31 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120105', 'Dez 31 2012 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1575.0000000, '', 'Jan 28 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120106', 'Dez 31 2012 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 1567.5000000, '', 'Jan  4 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20120107', 'Dez 31 2012 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 2024.0000000, '', 'Jan 30 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130001', 'Jan 31 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 240.0000000, '', 'Feb 26 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130002', 'Jan 31 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 420.0000000, '', 'Feb 11 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130003', 'Jan 31 2013 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 350.0000000, '', 'Mr  4 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130004', 'Jan 31 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 12380.0000000, '', 'Feb 28 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130005', 'Jan 31 2013 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 1657.5000000, '', 'Feb 26 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130006', 'Jan 31 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 60.0000000, '', 'Feb 28 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130007', 'Jan 31 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 3135.0000000, '', 'Feb 18 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130008', 'Feb 11 2013 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 1656.0000000, '', 'Mai 16 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130010', 'Feb 21 2013 12:00AM', 'tef-dokumentation Technische Dokumentation und Softwareentwicklung', 'Angelestrasse 56', 'DE ', '88214', 'Ravensburg', 460.0000000, '', 'Feb 26 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130011', 'Feb 28 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 180.0000000, '', 'Apr  3 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130012', 'Feb 28 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 160.0000000, '', 'Mr  7 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130013', 'Feb 28 2013 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 1470.0000000, '', 'Apr  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130014', 'Feb 28 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 12960.0000000, '', 'Mr 28 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130015', 'Feb 28 2013 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 1848.7500000, '', 'Apr 23 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130009', 'Feb 28 2013 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 828.0000000, '', 'Mr 20 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130016', 'Feb 28 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 3515.0000000, '', 'Apr  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130017', 'Mr 31 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 280.0000000, '', 'Mai  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130018', 'Mr 31 2013 12:00AM', 'Brstner GmbH', 'Weststrae 33', 'DE ', '77694', 'Kehl', 617.5000000, '', 'Mai  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130019', 'Mr 31 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 13440.0000000, '', 'Apr 29 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130020', 'Mr 31 2013 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 1020.0000000, '', 'Mai  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130021', 'Mr 31 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 140.0000000, '', 'Apr 26 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130022', 'Mr 31 2013 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1620.0000000, '', 'Mai  5 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130023', 'Mr 31 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 1472.5000000, '', 'Apr 29 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130024', 'Apr 30 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 240.0000000, '', 'Aug  6 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130025', 'Apr 30 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 400.0000000, '', 'Mai 28 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130026', 'Apr 30 2013 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 1050.0000000, '', 'Mai 31 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130027', 'Apr 30 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 12480.0000000, '', 'Jun  5 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130028', 'Apr 30 2013 12:00AM', 'EDC-Business IT-Consulting GmbH', 'Grner Weg 9', 'DE ', '61384', 'Bad Homburg', 700.0000000, '', 'Mai  8 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130029', 'Apr 30 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 142.5000000, '', 'Mai 27 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130030', 'Apr 30 2013 12:00AM', 'Lionbridge Poland Sp. z o.o.', 'ul. Jutrzenki 183', 'PL ', '02-231', 'Warsaw', 4800.0000000, '', 'Jul 18 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130031', 'Apr 30 2013 12:00AM', 'ORDIX AG', 'Westernmauer 12 - 16', 'DE ', '33098', 'Paderborn', 200.0000000, '', 'Jun  7 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130032', 'Apr 30 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 340.0000000, '', 'Mai 29 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130033', 'Apr 30 2013 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 1012.0000000, '', 'Mai 28 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130034', 'Mai  6 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 332.5000000, '', 'Mai 27 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130035', 'Mai 31 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 60.0000000, '', 'Jul  1 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130036', 'Mai 31 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 180.0000000, '', 'Jun 17 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130037', 'Mai 31 2013 12:00AM', 'Brstner GmbH', 'Weststrae 33', 'DE ', '77694', 'Kehl', 546.2500000, '', 'Jun 28 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130038', 'Mai 31 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 12400.0000000, '', 'Jul  3 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130039', 'Mai 31 2013 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 1950.0000000, '', 'Jul  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130040', 'Mai 31 2013 12:00AM', 'Herrenknecht AG', 'Schlehenweg 2', 'DE ', '77963', 'Schwanau', 760.0000000, '', 'Aug  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130041', 'Mai 31 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 60.0000000, '', 'Jun 26 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130042', 'Jun 30 2013 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 2530.0000000, '', 'Jul  4 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130043', 'Jun 30 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 340.0000000, '', 'Aug  1 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130044', 'Jun 30 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 300.0000000, '', 'Jul 12 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130045', 'Jun 30 2013 12:00AM', 'avato consulting AG', 'Siemensstr. 24  26', 'DE ', '63755', 'Alzenau', 2590.0000000, '', 'Jul 30 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130046', 'Jun 30 2013 12:00AM', 'Brstner GmbH', 'Weststrae 33', 'DE ', '77694', 'Kehl', 47.5000000, '', 'Jul 31 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130047', 'Jun 30 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 11520.0000000, '', 'Jul 31 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130048', 'Jun 30 2013 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 3825.0000000, '', 'Jul 14 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130049', 'Jun 30 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 570.0000000, '', 'Aug  5 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130050', 'Jun 30 2013 12:00AM', 'KLNDATA Professional IT Services GmbH Wissenschaftspark Osnabrck', 'Sedanstrasse 61', 'DE ', '49076', 'Osnabrck', 2100.0000000, '', 'Jul 30 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130051', 'Jun 30 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 60.0000000, '', 'Jul 15 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130052', 'Jul 18 2013 12:00AM', 'Stefan Schrer Projektbetreuung GmbH', 'Ostring 14', 'DE ', '49661', 'Cloppenburg', 1800.0000000, '', 'Jul 22 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130053', 'Jul 31 2013 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 3542.0000000, '', 'Aug  7 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130054', 'Jul 31 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 400.0000000, '', 'Sep  4 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130055', 'Jul 31 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 1100.0000000, '', 'Aug  5 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130056', 'Jul 31 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 10240.0000000, '', 'Sep  2 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130057', 'Jul 31 2013 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1530.0000000, '', 'Aug 30 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130058', 'Jul 31 2013 12:00AM', 'Stefan Schrer Projektbetreuung GmbH', 'Ostring 14', 'DE ', '49661', 'Cloppenburg', 4500.0000000, '', 'Aug  1 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130059', 'Jul 31 2013 12:00AM', 'Swiss Post Solutions GmbH Division Document Output', 'Kirchheimer Strae 177', 'DE ', '73265', 'Dettingen u. Teck', 47.5000000, '', 'Sep 19 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130060', 'Aug 31 2013 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 704.0000000, '', 'Okt 21 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130061', 'Aug 31 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 280.0000000, '', 'Okt  1 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130062', 'Aug 31 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 340.0000000, '', 'Nov 13 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130063', 'Aug 31 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 14080.0000000, '', 'Okt  1 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130064', 'Aug 31 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 570.0000000, '', 'Aug 27 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130065', 'Aug 31 2013 12:00AM', 'salamon | it-service', 'Friedrichsplatz 11', 'DE ', '34117', 'Kassel', 712.5000000, '', 'Sep  3 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130066', 'Sep 30 2013 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 1606.0000000, '', 'Okt  4 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130067', 'Sep 30 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 80.0000000, '', 'Okt 21 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130068', 'Sep 30 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 9600.0000000, '', 'Nov  4 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130069', 'Sep 30 2013 12:00AM', 'IDAP GmbH', 'Leyboldstrae 12', 'DE ', '50354', 'Hrth', 760.0000000, '', 'Okt 16 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130070', 'Sep 30 2013 12:00AM', 'salamon | it-service', 'Friedrichsplatz 11', 'DE ', '34117', 'Kassel', 1045.0000000, '', 'Okt  9 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130071', 'Sep 30 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 40.0000000, '', 'Okt 29 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130073', 'Sep 30 2013 12:00AM', 'Stefan Schrer Projektbetreuung GmbH', 'Ostring 14', 'DE ', '49661', 'Cloppenburg', 2700.0000000, '', 'Okt  8 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130074', 'Okt  2 2013 12:00AM', 'Stefan Schrer Projektbetreuung GmbH', 'Ostring 14', 'DE ', '49661', 'Cloppenburg', 2520.0000000, '', 'Okt  8 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130072', 'Sep 30 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 1377.5000000, '', 'Okt 28 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130075', 'Sep 30 2013 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 1080.0000000, '', 'Nov  1 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130076', 'Okt  7 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 332.5000000, '', 'Nov 11 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130077', 'Okt 31 2013 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 990.0000000, '', 'Nov 22 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130078', 'Okt 31 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 220.0000000, '', 'Jan  6 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130079', 'Okt 31 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 380.0000000, '', 'Nov 13 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130080', 'Okt 31 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 10200.0000000, '', 'Dez  3 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130081', 'Okt 31 2013 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 4465.0000000, '', 'Jan 15 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130082', 'Okt 31 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 380.0000000, '', 'Nov 27 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130083', 'Okt 31 2013 12:00AM', 'Stefan Schrer Projektbetreuung GmbH', 'Ostring 14', 'DE ', '49661', 'Cloppenburg', 2520.0000000, '', 'Nov  4 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130084', 'Nov 30 2013 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 2332.0000000, '', 'Dez  6 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130085', 'Nov 30 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 212.5000000, '', 'Jan  6 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130086', 'Nov 30 2013 12:00AM', 'BRABENDER Solutions GmbH', 'Gewerbestr. 5a', 'CH ', '6314', 'Untergeri', 688.7500000, '', 'Jan 10 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130087', 'Nov 30 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 14280.0000000, '', 'Jan  3 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130088', 'Nov 30 2013 12:00AM', 'IDAP GmbH', 'Leyboldstrae 12', 'DE ', '50354', 'Hrth', 760.0000000, '', 'Dez  3 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130089', 'Nov 30 2013 12:00AM', 'ProTechnology GmbH', 'Antonstrae 3a', 'DE ', '01097', 'Dresden', 997.5000000, '', 'Jan  3 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130090', 'Nov 30 2013 12:00AM', 'Robert Koch Institut', 'Nordufer 20', 'DE ', '13302', 'Berlin', 2900.0000000, '', 'Dez 23 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130091', 'Nov 30 2013 12:00AM', 'salamon | it-service', 'Friedrichsplatz 11', 'DE ', '34117', 'Kassel', 71.2500000, '', 'Dez  8 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130092', 'Nov 30 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 85.0000000, '', 'Dez 23 2013 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130093', 'Dez 31 2013 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 506.0000000, '', 'Jan 26 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130094', 'Dez 31 2013 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 297.5000000, '', 'Jan  6 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130095', 'Dez 31 2013 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 63.7500000, '', 'Feb  7 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130096', 'Dez 31 2013 12:00AM', 'BRABENDER Solutions GmbH', 'Gewerbestr. 5a', 'CH ', '6314', 'Untergeri', 142.5000000, '', 'Feb 28 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130097', 'Dez 31 2013 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 14280.0000000, '', 'Jan 28 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130098', 'Dez 31 2013 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 4892.5000000, '', 'Jan  8 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130099', 'Dez 31 2013 12:00AM', 'HeLaBa Landesbank Hessen-Thringen', 'Neue Mainzer Str. 52-58', 'DE ', '60311', 'Frankfurt am Main', 285.0000000, '', 'Jan 27 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130100', 'Dez 31 2013 12:00AM', 'ProTechnology GmbH', 'Antonstrae 3a', 'DE ', '01097', 'Dresden', 142.5000000, '', 'Jan 31 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130101', 'Dez 31 2013 12:00AM', 'salamon | it-service', 'Friedrichsplatz 11', 'DE ', '34117', 'Kassel', 403.7500000, '', 'Jan  2 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20130102', 'Dez 31 2013 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 42.5000000, '', 'Jan 28 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140001', 'Jan 31 2014 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 1672.0000000, '', 'Feb 11 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140002', 'Jan 31 2014 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 21.2500000, '', 'Mr  3 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140003', 'Jan 31 2014 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 170.0000000, '', 'Feb  7 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140004', 'Jan 31 2014 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 11560.0000000, '', 'Mr  4 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140005', 'Jan 31 2014 12:00AM', 'ProTechnology GmbH', 'Antonstrae 3a', 'DE ', '01097', 'Dresden', 403.7500000, '', 'Mr  7 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140006', 'Jan 31 2014 12:00AM', 'Q_PERIOR AG', 'Bavariaring 28', 'DE ', '80336', 'Mnchen', 8400.0000000, '', 'Feb 27 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140007', 'Jan 31 2014 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 340.0000000, '', 'Mr  3 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140008', 'Jan 31 2014 12:00AM', 'LB Immobilien Bewertungsgesellschaft mbH', 'Brienner Strasse 18', 'DE ', '80333', 'Mnchen', 2232.5000000, '', 'Feb 28 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140009', 'Feb 28 2014 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 352.0000000, '', 'Mr 11 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140010', 'Feb 28 2014 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 42.5000000, '', 'Apr  1 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140011', 'Feb 28 2014 12:00AM', 'cleversoft CRM Services GmbH', 'Paul-Heyse-Str. 6', 'DE ', '80336', 'Mnchen', 1687.5000000, '', 'Mr 14 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140012', 'Feb 28 2014 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 12920.0000000, '', 'Mr 28 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140013', 'Feb 28 2014 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 3040.0000000, '', 'Mr 13 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140014', 'Feb 28 2014 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 190.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140015', 'Feb 28 2014 12:00AM', 'Q_PERIOR AG', 'Bavariaring 28', 'DE ', '80336', 'Mnchen', 2520.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140016', 'Feb 28 2014 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 85.0000000, '', 'Mr 24 2014 12:00AM', 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140017', 'Feb 28 2014 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 1870.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140018', 'Mr 31 2014 12:00AM', 'allnabout GmbH', 'Hermannstrae 54', 'DE ', '63263', 'Neu-Isenburg', 3476.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140019', 'Mr 31 2014 12:00AM', 'American Chamber of Commerce in Belgium', 'Rue du Trone', 'BE ', '1050', 'Bruxelles', 85.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140020', 'Mr 31 2014 12:00AM', 'American Chamber of Commerce in Germany e.V.', 'Brsenplatz 7 - 11', 'DE ', '60313', 'Frankfurt am Main', 85.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140021', 'Mr 31 2014 12:00AM', 'BRABENDER Solutions GmbH', 'Gewerbestr. 5a', 'CH ', '6314', 'Untergeri', 118.7500000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140022', 'Mr 31 2014 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 14280.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140023', 'Mr 31 2014 12:00AM', 'Hays AG', 'Willy-Brandt-Platz 1-3', 'DE ', '68161', 'Mannheim', 1520.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140024', 'Mr 31 2014 12:00AM', 'Helaba Gesellschaft fr Immobilienbewertung mbH', 'Neue Mainzer Strae 52-58', 'DE ', '60311', 'Frankfurt am Main', 1140.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140025', 'Mr 31 2014 12:00AM', 'ProTechnology GmbH', 'Antonstrae 3a', 'DE ', '01097', 'Dresden', 23.7500000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140026', 'Mr 31 2014 12:00AM', 'salamon | it-service', 'Friedrichsplatz 11', 'DE ', '34117', 'Kassel', 1045.0000000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140027', 'Mr 31 2014 12:00AM', 'Swiss-American Chamber of Commerce', 'Talacker 41', 'CH ', '8001', 'Zurich', 233.7500000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140028', 'Mr 31 2014 12:00AM', 'DST Consulting GmbH', 'Zettachring 8', 'DE ', '70567', 'Stuttgart', 10518.7500000, '', NULL, 0);
INSERT INTO dbo.Invoices(InvoiceNumber, InvoiceDate, CustomerName, InvoiceStreet, InvoiceCCode, InvoiceZIP, InvoiceCity, InvoiceAmount, InvoiceCurrency, InvoicePaymentDate, Customer_Id) VALUES ('20140029', 'Mr 31 2014 12:00AM', 'Karl Donaubauer', 'Grinzinger Allee 5/14', 'DE ', '1190', 'Wien', 750.0000000, '', NULL, 0);

-- Aktualisierung der Customer_Id
UPDATE	i
SET		i.Customer_Id = c.Id
FROM	dbo.Invoices i INNER JOIN dbo.Customer c
		ON (i.CustomerName = c.CustomerName)
WHERE	i.Customer_Id = 0;
GO

UPDATE	dbo.invoices
SET		Customer_Id = 11
WHERE	CustomerName = 'American Chamber of Commerce  in Germany e.V.' AND
		Customer_Id = 0;

UPDATE	dbo.invoices
SET		Customer_Id = 19
WHERE	CustomerName = 'avato consulting GmbH' AND
		Customer_Id = 0;

UPDATE	dbo.invoices
SET		Customer_Id = 33
WHERE	CustomerName LIKE 'Deutsche Bank (Suisse) S.A.%' AND
		Customer_Id = 0;

UPDATE	dbo.invoices
SET		Customer_Id = 39
WHERE	CustomerName LIKE 'EDC-Business%' AND
		Customer_Id = 0;


UPDATE	dbo.invoices
SET		Customer_Id = 40
WHERE	CustomerName LIKE 'LIONBr%' AND
		Customer_Id = 0;
GO

UPDATE	dbo.invoices
SET		Customer_Id = 60
WHERE	CustomerName LIKE 'Fundacja Amerykanskiej Izby Handlowej%' AND
		Customer_Id = 0;
GO

UPDATE	dbo.invoices
SET		Customer_Id = 12
WHERE	CustomerName LIKE 'GIB%' AND
		Customer_Id = 0;
GO

UPDATE	dbo.invoices
SET		Customer_Id = 2
WHERE	CustomerName LIKE 'Entory%' AND
		Customer_Id = 0;
GO

RAISERROR ('Database, tables and data have been created for tests', 0, 1) WITH NOWAIT;
GO